from nipy.testing import Tester
test = Tester().test
bench = Tester().bench
